@@ -400,6 +400,9 @@ typedef struct RumState
 
 /* rumutil.c */
 extern bytea *rumoptions(Datum reloptions, bool validate);
+extern bool rumproperty(Oid index_oid, int attno,
+			 IndexAMProperty prop, const char *propname,
+			 bool *res, bool *isnull);
 extern Datum rumhandler(PG_FUNCTION_ARGS);
 extern void initRumState(RumState * state, Relation index);
 extern Buffer RumNewBuffer(Relation index);
@@ -1054,4 +1057,19 @@ extern Datum FunctionCall10Coll(FmgrInfo *flinfo, Oid collation,
 				   Datum arg6, Datum arg7, Datum arg8,
 				   Datum arg9, Datum arg10);
 
+/* PostgreSQL version-agnostic creation of memory context */
+#if PG_VERSION_NUM >= 110000
+	#define RumContextCreate(parent, name) \
+		AllocSetContextCreateExtended(parent, name, \
+									  ALLOCSET_DEFAULT_MINSIZE, \
+									  ALLOCSET_DEFAULT_INITSIZE, \
+									  ALLOCSET_DEFAULT_MAXSIZE)
+#else
+	#define RumContextCreate(parent, name) \
+		AllocSetContextCreate(parent, name, \
+							  ALLOCSET_DEFAULT_MINSIZE, \
+							  ALLOCSET_DEFAULT_INITSIZE, \
+							  ALLOCSET_DEFAULT_MAXSIZE)
+#endif
+
 #endif   /* __RUM_H__ */
